@@ -215,7 +215,7 @@ var Flashblock = {
 
 		// Work around about: and file:// URIs.
 		// If we do uri.spec = "about:blank", the URI ends up as about://blank/
-		if(/about:|file:/i.test(pageURI.protocol))
+		if(/about:|file:|news:|snews:/i.test(pageURI.protocol))
 			return null;
 
 		var uri = Components.classes['@mozilla.org/network/standard-url;1']
@@ -273,10 +273,13 @@ var Flashblock = {
 /// CONTEXT MENU FUNCTIONS
 
     contextMenuInit : function () {
-        var cm = document.getElementById("contentAreaContextMenu");
+      var items = ["contentAreaContextMenu", "messagePaneContext"];
+      for (var i = 0; i < items.length; i++) {
+        var cm = document.getElementById(items[i]);
         if (cm)
-            cm.addEventListener("popupshowing",Flashblock.contextMenu,false);
-        Flashblock.setButtonState(Flashblock.isEnabled());
+          cm.addEventListener("popupshowing",Flashblock.contextMenu,false);
+      }
+      Flashblock.setButtonState(Flashblock.isEnabled());
     },
 
     // was flashblockContextMenu()
@@ -398,13 +401,17 @@ var Flashblock = {
       var isJavascriptEnabled = FBlockUtils.isJavascriptEnabled();
         var button = document.getElementById("flashblockToggle-button");
         if (button) {
-            button.setAttribute("state", state? "enabled" : "disabled");
+            button.setAttribute("state", state ? "enabled" : "disabled");
             button.setAttribute("disabled", !isJavascriptEnabled);
+            button.setAttribute("label",
+              button.getAttribute(state ? "labelon" :"labeloff"));
         }
         button = document.getElementById("flashblockMozToggle-button");
         if (button) {
-            button.setAttribute("state", state? "enabled" : "disabled");
+            button.setAttribute("state", state ? "enabled" : "disabled");
             button.setAttribute("disabled", !isJavascriptEnabled);
+            button.setAttribute("label",
+              button.getAttribute(state ? "labelon" :"labeloff"));
         }
     },
 
@@ -492,7 +499,7 @@ var Flashblock = {
 
         if(prefs.getPrefType("flashblock.silverlight.blocked") == prefs.PREF_BOOL)
             return prefs.getBoolPref("flashblock.silverlight.blocked");
-        return true;
+        return false;
     }
 }
 
