@@ -3,5 +3,5 @@ pref("flashblock.enabled",true);
 pref("flashblock.whitelist", "");
 pref("flashblock.blockLocal",false);
 pref("browser.toolbars.showbutton.flashblockMozToggle", false);
-pref("flashblock.silverlight.blocked",true);
+pref("flashblock.silverlight.blocked",false);
 pref("flashblock.java.blocked",true);
